@@ -34,10 +34,6 @@ class ShortCutterLinux(ShortCutter):
     def _get_bin_folder_pyexe():
         return p.dirname(sys.executable)
 
-    @staticmethod
-    def _get_local_root():
-        return p.dirname(p.dirname(sys.executable))
-
     @staticmethod
     def _get_activate_wrapper_templates():
         return ACTIVATE, ACTIVATE_PROMPT
